<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>

<script type="text/javascript">
  try{
    parent._composeMusicResponse = <?php echo $this->jsonInline($this->getVars()) ?>;
  } catch(err){ console.log(err); };
</script>
