<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Music_Form_Admin_Widget_HomePlaylist extends Core_Form_Admin_Widget_Standard
{
  public function init()
  {
    parent::init();

    // Set form attributes
    $this
      ->setTitle('Home Playlist')
      ->setDescription('Please choose a playlist.')
      ;
    
    // Element: poll_id
    $this->addElement('Hidden', 'playlist_id', array(
      'allowEmpty' => false,
      'required' => true,
    ));
  }
}
