<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Music_Model_DbTable_Songs extends Engine_Db_Table
{
  #protected $_name = 'songs';
  protected $_rowClass = 'Music_Model_Song';
}
