INSERT IGNORE INTO `engine4_core_menuitems` (`name`, `module`, `label`, `plugin`, `params`, `menu`, `submenu`, `order`) VALUES ('core_main_quickcreate_music', 'music', 'Upload Music', 'Music_Plugin_Menus::canCreatePlaylists', '{"route":"music_general","action":"create","icon":"fi fi-rr-music-alt"}', 'core_main_quickcreate', '', 8);

UPDATE `engine4_core_menuitems` SET `params` = '{"route":"music_general","action":"browse","icon":"fi fi-rr-music-alt"}' WHERE `engine4_core_menuitems`.`name` = 'core_main_music';

UPDATE `engine4_core_menuitems` SET `description` = 'Express yourself through your favorite music' WHERE `engine4_core_menuitems`.`name` = 'core_main_music';