<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Music_Model_DbTable_PlaylistSongs extends Engine_Db_Table
{
  protected $_name     = 'music_playlist_songs';
  //protected $_primary  = array('playlist_id', 'file_id');
  protected $_primary  = 'song_id';
  
  protected $_rowClass = 'Music_Model_PlaylistSong';
}
