
/*
BROWSE MUSIC
Styles the music browse page.
*/
.music_listing_item article{
  background-color:var(--theme-list-background-color);
  border-radius:var(--theme-item-radius);
  transition:var(--theme-item-transition);
  box-shadow:var(--theme-item-shadow);
  padding:var(--theme-item-spacing);
}
.music_listing > li + li{
  margin-top:var(--theme-item-spacing);
}
.music_browse_author_photo{
  height:3rem;
  width:3rem;
}
.music_browse_info{
  flex:1;
  overflow:hidden;
}
.music_browse_info .music_playlist_stats{
  margin-bottom:0;	
	font-size:var(--theme-font-size-small);
  color:var(--theme-font-color-light);
}
.music_browse_info .music_playlist_stats span + span{
  margin-left:0.3125rem;
}
[dir="rtl"] .music_browse_info .music_playlist_stats span + span{
  margin-left:0.3125rem;
  margin-right:0rem;
}
.music_browse_info .music_playlist_stats span i{
  margin-right:0.125rem;
}
[dir="rtl"] .music_browse_info .music_playlist_stats span i{
  margin-left:0.125rem;
  margin-right:0;
}
.music_browse_info .music_playlist_stats .star_rating_wrapper{
  display:inline-flex;
  margin-left:0.3125rem;
}
[dir="rtl"] .music_browse_info .music_playlist_stats .star_rating_wrapper{
  margin-right:0.3125rem;
  margin-left:0;
}
.music_browse_info_title{
  font-weight:600;
}
.music_browse_info_date{
  font-size:var(--theme-font-size-small);
  color:var(--theme-font-color-light);
  flex:1;
  overflow:hidden;
}
.music_browse_info_desc{
  margin-top:0.5rem;
}
.music_browse_info_desc > p{
	margin-bottom:0;
}
/*
VIEW PLAYLIST
Styles the view playlist page, where a single
playlist is viewed.
*/
.music_view_header_info,
.music_view_header_info_left{
  flex:1;
}
.music_playlist_info_date{
  color:var(--theme-font-color-light);
  font-size:var(--theme-font-size-small);
}
.music_playlist .music_playlist_stats{
  border-top-width:0.0625rem;
  margin-top:0.9375rem;
  padding-top:0.9375rem;
}
.music_playlist .music_playlist_stats > a{
  font-weight:var(--theme-font-weight-bold);
	font-size:100%;
  line-height:inherit !important;
}
.music_playlist_info_rating{
  margin:0.25rem 0;
}
/*sidebar*/
.sidebar_list .sidebar_list_item_stats{
  margin-top:0.125rem;
}
.sidebar_list .bg_item_nophoto:before{
 font-size:1.5625rem;
}
/*Profile Page*/
.music_profile_browse li + li{
  margin-top:var(--theme-item-spacing);
}
.music_profile_browse article{
  background-color:var(--theme-list-background-color);
  border-radius:var(--theme-item-radius);
  transition:var(--theme-item-transition);
  box-shadow:var(--theme-item-shadow);
  padding:var(--theme-item-spacing);
}
.music_profile_browse .playlist_short_player{
  margin-top:0.125rem;
}
.music_profile_browse .music_playlist_stats{
  margin-bottom:0;
}
/*MUSIC PLAYER SKIN*/
.music_player{
  border-radius: var(--theme-item-radius);
  width:100%;
  background-color:#2c2e3c;
  border:4px solid var(--theme-border-color);
  margin:10px 0px 10px 0px;
  padding:10px;
  max-width:100%;
  box-sizing:border-box;
}
.music_player_top{
  overflow:hidden;
}
.music_player_art{
  float:left;
  overflow:hidden;
  width:100px;
  margin-right:10px;
}
.music_player_art .bg_item_photo {
  padding-bottom:100%;
  border:3px solid #3f4e61;
}
.music_player_info{
  overflow:hidden;
}
.music_player_controls_wrapper{
  display:flex;
}
.music_player_controls_left{
  flex:1;
}
.playlist_player_loaded .music_player_controls_left{
  overflow:hidden;
}
.music_player_controls_volume{
  float:left;
  overflow:hidden;
  width:40px;
  height:30px;
  margin-left:10px;
  display:flex;
  align-items:center;
}
.music_player_controls_volume_toggle:before{
  display:block;
  height:12px;
  margin-right:3px;
  content:"\f144";
  cursor:pointer;
}
.music_player_controls_volume_toggle_mute:before{
  content:"\f144";
}
.music_player_controls_volume_bar{
  display:block;
  margin-top:8px;
  height:20px;
  width:4px;
  cursor:pointer;
  padding:0px 1px 0px 0px;
}
.music_player_controls_volume_bar > span{
  width:3px;
  display:block;
  background-color:#ccc;
}
.music_player_controls_volume_enabled > span,
.music_player_controls_volume_hover > span,
.music_player_controls_volume_bar:hover > span{
  background-color:#fff;
}
.volume_bar_1{
  margin-top:8px;
  height:4px;
}
.volume_bar_2{
  margin-top:6px;
  height:8px;
}
.volume_bar_3{
  margin-top:4px;
  height:12px;
}
.volume_bar_4{
  margin-top:2px;
  height:16px;
}
.volume_bar_5{
  margin-top:0px;
  height:20px;
}
.music_player_controls_right{
  overflow:hidden;
  text-align:right;
}
.music_player_button_launch_tooltip{
  border-radius:3px;
  display:none;
  position:absolute;
  background:#222;
  opacity:.9;
  color:#fff;
  text-align:center;
  padding:5px;
  width:110px;
  font-size:var(--theme-font-size-small);
  margin-top:-25px;
  margin-left:-49px;
  z-index:1;
}
.music_player_button_launch_wrapper:hover .music_player_button_launch_tooltip{
  display:block;
}
.music_player_button_prev,
.music_player_button_play,
.music_player_button_pause,
.music_player_button_next,
.music_player_button_launch{
  border-radius:6px;
  display:block;
  float:left;
  overflow:hidden;
  width:25px;
  height:25px;
  background-color:#3f4e61;
  margin-top:4px;
  font-size:16px;
  outline:none;
  text-align:center;
}
.music_player_button_prev:before,
.music_player_button_play:before,
.music_player_button_pause:before,
.music_player_button_next:before,
.music_player_button_launch:before,
.music_player_controls_volume_toggle:before{
  font-family:'Font Awesome 6 Free';
  color:#fff;
  vertical-align:middle;
}
.music_player_button_prev:before{
  content:"\f048";
	font-weight:900;
}
.music_player_button_next:before{
  content:"\f051";
	font-weight:900;
}
.music_player_button_launch{
  -ms-filter:"progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
  -webkit-transform:rotate(90deg);
  -ms-transform:rotate(90deg);
  transform:rotate(90deg);
}
.music_player_button_launch:before{
  margin-top:4px;
  content:"\f048";
	font-weight:900;
}
.music_player_button_launch:hover{
  text-decoration:none;
}
.music_player_button_play{
  margin:2px 3px 0px 3px;
  width:34px;
  height:34px;
  font-size:21px;
  display:flex;
  align-items:center;
  justify-content:center;  
}
.music_player_button_play:before{
  content:"\f04b";
	font-weight:900;
}
.music_player_button_pause:before{
  content:"\f04c";
}
.music_player_button_prev:hover,
.music_player_button_play:hover,
.music_player_button_next:hover,
.music_player_button_launch:hover{
  background-color:#2b3849;
  cursor:pointer;
}
.music_player_trackname{
  margin-top:5px;
  font-size:8pt;
  font-weight:bold;
  color:#fff;
  overflow:hidden;
}
.music_player .audiojs{
  border-radius:3px;
  background-color:#3f4e61;
  display:flex;
  margin-top:10px;
  width:100%;
}
.music_player .audiojs .play-pause{
  display:none;
}
.music_player .audiojs audio
{
  position:absolute;
  left:-1px;
}
.music_player .audiojs .scrubber{
  background:#2b3849;
  flex:1;
  position:relative;
  height:14px;
  margin:10px;
  overflow:hidden;
}
.music_player .audiojs .loaded{
  position:absolute;
  top:0px;
  left:0px;
  height:14px;
  width:0px;
  background:#000;
}
.music_player .audiojs .progress{
  background:#ccc;
  position:absolute;
  top:0px;
  left:0px;
  height:14px;
  width:0px;
  z-index:1; 
} 
.music_player .audiojs .time{ 
  display:flex;
  align-items:center;
  padding:0px 6px 0px 12px;
  border-left:1px solid #000;
  color:#ddd;
  text-shadow:1px 1px 0px rgba(0,0,0,0.5);
  font-size:var(--theme-font-size-small);
} 
.music_player .audiojs .time em{
  padding:0px 2px 0px 0px;
  color:#f9f9f9;
  font-style:normal;
} 
.music_player .audiojs .time strong{
  padding:0px 0px 0px 2px;
  font-weight:normal;
}
.music_player_tracks{
  border:1px solid #2b3849;
  margin-top:10px;
  overflow:hidden;
  overflow-y:auto;
  max-height:95px;
}
.music_player_tracks > li{
  overflow:hidden;
  background-color:#3f4e61;
  padding:5px 7px 5px 7px;
}
.music_player_tracks > li + li{
  margin-top:1px;
}
.music_player_tracks > li:hover,
.music_player_tracks > li.song_playing{
  background-color:#2b3849;
  cursor:pointer;
}
.music_player_tracks > li > div,
.music_player_tracks > li > div span{
  font-size:0.6875rem;
  color:#eee;
}
.music_player_tracks .music_player_tracks_name{
  overflow:hidden;
  -moz-user-select:none;
  -webkit-user-select:none;
}
.music_player_tracks .music_player_tracks_name a{
  text-decoration:none;
  color:#eee;
  outline:none;
}
.music_player_tracks .music_player_tracks_plays{
  display:inline-block;
  color:#bbb;
  margin-left:5px;
  font-size:var(--theme-font-size-small);
}
.music_player_tracks .music_player_tracks_add_wrapper{
  float:right;
  overflow:hidden;
  text-align:right;
  font-weight:normal;
  -moz-user-select:none;
  -webkit-user-select:none;
}
.music_player_tracks .music_player_tracks_add_tooltip{
  border-radius:3px;
  display:none;
  position:absolute;
  background:#222;
  opacity:.9;
  color:#fff;
  text-align:center;
  padding:5px;
  width:120px;
  font-size:1.1em;
  margin-top:-30px;
  margin-left:-55px;
}
.music_player_tracks .music_player_tracks_add_wrapper:hover .music_player_tracks_add_tooltip{
  display:block;
}
.music_player_tracks .music_player_tracks_add_wrapper:hover .music_player_tracks_add:before{
  content:"\f067";
  font-family:'Font Awesome 6 Free';
  color:#fff;
	font-weight:900;
}
.music_player_tracks .music_player_tracks_add:before{
  display:inline-block;
  margin-left:5px;
  content:"\f067";
  width:9px;
  height:9px;
  outline:none;
  text-decoration:none;
  font-family:'Font Awesome 6 Free';
  color:rgba(255, 255, 255, .3);
	font-weight:900;
}

/*
ATTACHED MUSIC LAUNCH SKIN
This is a small version of the player. It doesn't actually play
tracks itself, but when clicked, loads the full player and initiates
playback of the first track. Some of its styles are inherited from
the full music player's skin.
*/
.playlist_short_player{
  border:none;
  padding:3px 0px 3px 0px;
  cursor:pointer;
}
.playlist_short_player .music_player_top{
  padding:2px 4px;
}
.playlist_short_player .music_player_button_play{
  margin-right:0.625rem;
  margin-left:0;
}
[dir="rtl"] .playlist_short_player .music_player_button_play{
  margin-left:0.625rem;
  margin-right:0;
}
.playlist_short_player_title{
  color:#fff;
  font-weight:bold;
  padding-right:10px;
}
.playlist_short_player_tracks{
  font-size:var(--theme-font-size-small);
  color:#bbb;
  font-weight:normal;
}
/*
ADD SONG TO PLAYLIST FORM
Styles the form that pops up when you click to add a song
to your playlist via a music player.
*/
#form-playlist-append .form-label{
  margin-bottom:2px;
}
#form-playlist-append #title-wrapper{
  margin-top:10px;
}
#form-playlist-append #submit-wrapper{
  margin-top:10px;
}

/* DEFAULT PHOTO THUMB */
.bg_item_nophoto.bg_item_photo_music_playlist:before{
  content:"\f51f";
}
.bg_item_nophoto.bg_item_photo_music_playlist.bg_thumb_icon:before{
  font-size:30px;
}
/* ITEM TYPE ICONS */
.item_icon_music:before,
.item_icon_music_playlist:before,
.item_icon_music_song:before,
.activity_icon_music_playlist_new:before,
.item_icon_music_playlist_song:before{
  content:"\ed9f";
  font-family: uicons-regular-rounded !important;
  font-weight:400 !important;
}
#compose-music-activator:before,
#compose-music-menu span:before{
  content:"\ed9f";
  font-family: uicons-regular-rounded !important;
  font-weight:400 !important;
  margin-right:6px;
}
[dir="rtl"] #compose-music-activator:before,
[dir="rtl"] #compose-music-menu span:before{
  margin-right:0px;
  margin-left:6px;
}
#compose-music-form-fancy-file:before{
  content:"\f001";
  font-weight:900 !important;
}
a.compose-music-link:before{
  content:"\f144";
  font-family:'Font Awesome 6 Free';
  margin-right:6px;
}
a.compose-music-link-playing:before{
  content:"\f110";
  display:inline-flex;
  font-weight: 900;
  font-family: 'Font Awesome 6 Free';
  -webkit-animation:spinning 2s infinite linear;
  animation:spinning 2s infinite linear;
}
[dir="rtl"] a.compose-music-link,
[dir="rtl"] a.compose-music-link-playing{
  padding-left:0px;
  padding-right:20px;
}
/*
POPUP MUSIC PLAYER SKIN
Opens the player in a small new window.
*/
.music_player_popup{
  background-color:#2c2e3c;
  padding-top:20px;
}
body#global_page_music-playlist-view #global_content_simple{
  display:block;
  width:100%;
}
body#global_page_music-playlist-view #global_content_simple .music_playlist_popout_wrapper{
  margin-left:auto;
  margin-right:auto;
  width:430px;
  max-width: 100%;
}
body#global_page_music-playlist-view #global_content_simple .music_player_button_launch,
body#global_page_music-playlist-view #global_content_simple .layout_core_comments{
  display:none;
}

/*
PROFILE MUSIC PLAYER
Styles the mini-player that only shows up on the member profile page.
*/
.layout_music_profile_player{
  margin-top:20px;
}
#profile_music_player{
  margin-top:5px;
}
#profile_music_player h3{
  display:none;
}
#profile_music_player .music_browse_info_date{
  margin-top:4px;
}
#profile_music_player .music_player_art{
  display:none;
}
#profile_music_player .music_player_button_prev,
#profile_music_player .music_player_button_next{
  display:none;
}
#profile_music_player .music_player_button_play{
  margin:0px;
}
#profile_music_player .music_player_trackname{
  font-weight:normal;
	font-weight:900 !important;
}
/* ICONS */
.icon_music_new:before{
  content:"\f067";
}
@media (max-width:767px) {
  .music_player_art{
     width:75px;
  }
}
@media (max-width:600px) {
  .music_browse_options{
    float:none;
    padding-left:0;
    margin:10px 0 5px 0;
  }
  .music_browse_options li{
    display:inline-block;
  }
  .music_playlist_info{
    clear:both;
    padding-top:5px;
  }
  .music_browse_options a{
    margin:0 5px 0 0;
    font-size:.75em;
  }
}