
UPDATE `engine4_core_menuitems` SET `params`='{"route":"music_general","action":"browse","icon":"fa fa-search"}' WHERE `name`='music_main_browse';
UPDATE `engine4_core_menuitems` SET `params`='{"route":"music_general","action":"manage","icon":"fa fa-user"}' WHERE `name`='music_main_manage';
UPDATE `engine4_core_menuitems` SET `params`='{"route":"music_general","action":"create","icon":"fa fa-upload"}' WHERE `name`='music_main_create';
